@@ -10,13 +10,13 @@ from email_extras.settings import USE_GNUPG, GNUPG_HOME, ALWAYS_TRUST
 
 if USE_GNUPG:
     from gnupg import GPG
-    from email_extras.models import Address
 
 
 def addresses_for_key(gpg, key):
     """
     Takes a key and extracts the email addresses for it.
     """
+    from email_extras.models import Address
     fingerprint = key["fingerprint"]
     addresses = []
     for key in gpg.list_keys():
@@ -39,17 +39,18 @@ def send_mail(subject, body_text, addr_from, addr_to, fail_silently=False,
         addr_to = [addr_to]
 
     # Obtain a list of the recipients that have gpg keys installed.
-    valid_key_addresses = []
+    key_addresses = {}
     if USE_GNUPG:
-        queryset = Address.objects.filter(address__in=addr_to)
-        valid_key_addresses = queryset.values_list("address", flat=True)
+        from email_extras.models import Address
+        for address in Address.objects.filter(address__in=addr_to):
+            key_addresses[address.address] = address.use_asc
         # Create the gpg object.
-        if valid_key_addresses:
+        if key_addresses:
             gpg = GPG(gnupghome=GNUPG_HOME)
 
     # Encrypts body if recipient has a gpg key installed.
     def encrypt_if_key(body, addr):
-        if addr in valid_key_addresses:
+        if addr in key_addresses:
             return unicode(gpg.encrypt(body, addr, always_trust=ALWAYS_TRUST))
         return body
 
@@ -67,11 +68,14 @@ def send_mail(subject, body_text, addr_from, addr_to, fail_silently=False,
     # Send emails.
     for addr in addr_to:
         msg = EmailMultiAlternatives(subject, encrypt_if_key(body_text, addr),
-            addr_from, [addr])
+                                     addr_from, [addr])
         if body_html is not None:
             msg.attach_alternative(encrypt_if_key(body_html, addr), "text/html")
         for parts in attachments_parts:
-            msg.attach(parts[0], encrypt_if_key(parts[1], addr))
+            name = parts[0]
+            if key_addresses.get(addr):
+                name += ".asc"
+            msg.attach(name, encrypt_if_key(parts[1], addr))
         msg.send(fail_silently=fail_silently)
 
 
